@@ -227,7 +227,18 @@ export const globalSettings = {
             },
           },
         },
+        mandatoryChartingEditReason: {
+          description: 'Require a reason for change text field to be filled out on chart edit',
+          type: yup.boolean(),
+          defaultValue: false,
+        },
+        enableChartingEdit: {
+          description: 'Allow existing charting records to be edited',
+          type: yup.boolean(),
+          defaultValue: false,
+        },
         desktopCharting: {
+          description: 'Enable desktop charting module',
           properties: {
             enabled: {
               type: yup.boolean(),
@@ -306,6 +317,16 @@ export const globalSettings = {
           type: yup.boolean(),
           defaultValue: false,
         },
+        pharmacyOrder: {
+          description: 'Pharmacy order settings',
+          properties: {
+            enabled: {
+              description: 'Enable pharmacy orders',
+              type: yup.boolean(),
+              defaultValue: false,
+            },
+          },
+        },
         useGlobalPdfFont: {
           description: 'Use the global PDF font for all PDFs',
           type: yup.boolean(),
@@ -917,6 +938,11 @@ export const globalSettings = {
         },
       },
     },
+    fileChooserMbSizeLimit: {
+      description: 'The maximum size in megabytes of files that can be uploaded with the file chooser',
+      type: yup.number().min(1),
+      defaultValue: 10,
+    },
     integrations: {
       name: 'Integrations',
       description: 'Integration settings',
